"""Added unique constraing to model set

Peek Plugin Database Migration Script

Revision ID: b0b08aff8542
Revises: 64309a77b48d
Create Date: 2017-07-13 20:48:40.825705

"""

# revision identifiers, used by Alembic.
revision = 'b0b08aff8542'
down_revision = '64309a77b48d'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint(None, 'LiveDbModelSet', ['name'], schema='pl_livedb')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'LiveDbModelSet', schema='pl_livedb', type_='unique')
    # ### end Alembic commands ###